// hts_view.cpp : Implementaion for the CHtsView Class
//
// This class is derived from the CTerView class.  Therefore, if your
// application derives a class from the CHtsView class and adds it
// to the template using CWinApp::AddDocTemplate, the framework
// will call both the constructor and the 'Create' function.
//
// Sub Systems, Inc.
// Copyright 1994.
// 159 Main Street, #8C
// Stoneham, MA 02180
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"

#include "hts_view.h"
#include "resource.h"

#ifdef _DEBUG
#undef THIS_FILE
static char BASED_CODE THIS_FILE[] = __FILE__;
#endif

// CHtsView

IMPLEMENT_DYNCREATE(CHtsView,CTerView)

BEGIN_MESSAGE_MAP(CHtsView, CTerView)
        //{{AFX_MSG_MAP(CHtsView)
        ON_WM_CREATE()
        //}}AFX_MSG_MAP

END_MESSAGE_MAP()

// CHtsView construction/destruction
CHtsView::CHtsView()
{
    // Variable initialization
    m_initialized=FALSE;         // TRUE when HtsInitialized called
}

CHtsView::~CHtsView()
{
}

// Return edit styles to be used with the window
WORD CHtsView::EditStyles()
{
    return TER_WORD_WRAP|TER_FITTED_VIEW|TER_READ_ONLY|TER_VSCROLL|TER_HSCROLL|TER_BORDER_MARGIN;  // control style
}

/////////////////////////////////////////////////////////////////////////////
// Called by MFC after creating the window
int CHtsView::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
    LRESULT FAR PASCAL HtsCallback(HWND,UINT,WPARAM,LPARAM);

    if (CView::OnCreate(lpCreateStruct) == -1) return -1;
    
    if (m_hWnd) {      // set the callback from TER dll
       ::TerRegisterVbxCallback(m_hWnd,(VBX_CALLBACK)HtsCallback);
       ::TerSetParentPtr(m_hWnd,(void far *)this);   // save the control pointer

       HtsInitialize(m_hWnd,GetParent()->m_hWnd);
       m_initialized=TRUE;
    }

    return 0;
}

/////////////////////////////////////////////////////////////////////////////
// Call HTS menu option
void CHtsView::HtsMenu(WPARAM MenuOption)
{
    if (HtsMenuEnable(MenuOption)) ::HtsCommand(m_hWnd,MenuOption);
}

BOOL CHtsView::HtsMenuEnable(int MenuItem)
{
    if (m_hWnd && ::HtsMenuEnable(m_hWnd,MenuItem)) return TRUE;
    else                                            return FALSE;

}

// Check if a menu item should be selected
int CHtsView::HtsMenuSelect(int MenuItem)
{
    if (m_hWnd && ::HtsMenuSelect(m_hWnd,MenuItem)) return 1;
    else                                            return 0;
}

/////////////////////////////////////////////////////////////////////////////
// File io functions
void CHtsView::DeleteContents()
{
    ASSERT_VALID(this);
    ASSERT(m_hWnd!=NULL);

    HtsClearWindow(m_hWnd);

    ASSERT_VALID(this);
}

// Read and write CHtsView object to archive, with a 4 byte length prefix.
void CHtsView::Serialize(CArchive& ar)
{
    ASSERT_VALID(this);
    ASSERT(m_hWnd != NULL);

    if (ar.IsStoring()) {        // Save data
        DWORD nLen = GetBuffer();
        ar << nLen;              // write length
        WriteArchive(ar);
    }
    else {                       // load data
        DWORD dwLen;
        ar >> dwLen;             // read length
        ReadArchive(ar, dwLen);
    }
    ASSERT_VALID(this);
}

// Read certain amount of text from the file, assume at least nLen
// bytes are in the file.
void CHtsView::ReadArchive(CArchive& ar, DWORD nLen)
{
    ASSERT_VALID(this);
    
    HGLOBAL hBuf=::GlobalAlloc(GMEM_MOVEABLE, nLen+1);
    char * pMem=(char *)GlobalLock(hBuf);

    if (pMem == NULL) {
        AfxThrowMemoryException();
        ASSERT(FALSE);
    }
    
    // read the buffer
    DWORD BlockSize=0x4000;       // 16 blocks
    DWORD BytesDone=0;            // bytes written so far

    while (BytesDone<nLen) {
       if ((BytesDone+BlockSize)>nLen) BlockSize=nLen-BytesDone;

       if (ar.Read(&(pMem[BytesDone]),(UINT)BlockSize)!=(UINT)BlockSize) {
          ::GlobalUnlock(hBuf);
          AfxThrowArchiveException(CArchiveException::endOfFile);
          ASSERT(FALSE);
       }
       BytesDone+=BlockSize;
    }
    
    // pass the handle to the control
    pMem[nLen]=0;
    ::GlobalUnlock(hBuf);

    HtsRead(m_hWnd,HTML_BUF,NULL,hBuf,nLen,NULL);

    ASSERT_VALID(this);
}

// Write just the text to an archive, no length prefix.
void CHtsView::WriteArchive(CArchive& ar)
{
    ASSERT_VALID(this);
    ASSERT(m_hBuffer!=NULL);

    char *pMem = (char *)::GlobalLock(m_hBuffer);

    ASSERT(pMem != NULL);

    // direct write for a huge buffer
    TRY
    {
       DWORD BlockSize=0x4000;       // 16 blocks
       DWORD BytesDone=0;            // bytes written so far

       while (BytesDone<m_BufLen) {
          if ((BytesDone+BlockSize)>m_BufLen) BlockSize=m_BufLen-BytesDone;
          ar.Write(&(pMem[BytesDone]),(UINT)BlockSize);
          BytesDone+=BlockSize;
       }
    }
    CATCH_ALL(e)
    {
        ::GlobalUnlock(m_hBuffer);
        THROW_LAST();
        ASSERT(FALSE);
    }
    END_CATCH_ALL
    
    // release our buffer
    ::GlobalUnlock(m_hBuffer);
    ::GlobalFree(m_hBuffer);
    m_hBuffer=0;
    m_BufLen=0;
    
    // mark the window as updated
    ::TerSetModify(m_hWnd,FALSE);

    ASSERT_VALID(this);
}

void CHtsView::SerializeRaw(CArchive& ar)
    // Read/Write object as stand-alone file.
{
    ASSERT_VALID(this);
    if (ar.IsStoring())  {   // save data
        GetBuffer();         // retrieve data from control
        WriteArchive(ar);
    }
    else {                   // load file
        CFile *pFile = ar.GetFile();
        ASSERT(pFile->GetPosition() == 0);
        DWORD nFileSize = pFile->GetLength();
        ReadArchive(ar,nFileSize);
    }
    ASSERT_VALID(this);
}

DWORD CHtsView::GetBuffer()
        // Retrieve the text buffer from the control
{
    BOOL result;

    if (m_hBuffer) ::GlobalFree(m_hBuffer);

    //m_hBuffer=::GetTerBuffer(m_hWnd,(long far *)&m_BufLen);
    result=::HtsSave(m_hWnd,HTML_BUF,NULL,&m_hBuffer,(long far *)&m_BufLen);

    return m_BufLen;
}

/////////////////////////////////////////////////////////////////////////////
/******************************************************************************
   HtsCallback:
   This function is called by the HTS DLL to pass the messages intended for the
   parent window.
******************************************************************************/
LRESULT FAR PASCAL _export HtsCallback(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
   class CHtsView far *pHtsView=(class CHtsView far *)::TerGetParentPtr(hWnd);
   
   return pHtsView->OnHtsMessage(message,wParam,lParam);
}

// CDemoView message handlers - placeholder routine
///////////////////////////////////////////////////////////////////////////
LRESULT CHtsView::OnHtsMessage(UINT message,WPARAM wParam,LPARAM lParam)
{
   return (LRESULT)FALSE;
}
